@@ -1,27 +1,22 @@
 #=Copyright Infomation
 #==========================================================
-#Module Name      : Religion::Islam::Qibla
-#Program Author   : Ahmed Amin Elsheshtawy
-#Home Page          : http://www.islamware.com
-#Contact Email      : support@islamware.com
-#Copyrights  2006 IslamWare. All rights reserved.
-#==========================================================
+#Module Name       : Religion::Islam::Qibla
+#Program Author   : Dr. Ahmed Amin Elsheshtawy, Ph.D. Physics, E.E.
+#Home Page           : http://www.islamware.com, http://www.mewsoft.com
+#Contact Email      : support@islamware.com, support@mewsoft.com
+#Copyrights  2006-2013 IslamWare. All rights reserved.
 #==========================================================
 package Religion::Islam::Qibla;
 
 use Carp;
 use strict;
-#use warnings;
-use Exporter;
+use warnings;
 
-our @ISA = qw(Exporter);
-our @EXPORT = qw();
+our $VERSION = '2.0';
 
-our $VERSION = '1.02';
-
-our $pi = 4 * atan2(1, 1),			# 3.1415926535897932;   # PI=22/7, Pi = Atn(1) * 4
-our $DtoR = $pi / 180;				# Degree to Radians
-our $RtoD = 180 / $pi;				# Radians to Degrees
+use constant PI => 4 * atan2(1, 1);	#3.1415926535897932 PI=22/7, Pi = Atn(1) * 4
+use constant DtoR => PI / 180;	# Degree to Radians
+use constant RtoD => 180 / PI;	# Radians to Degrees
 #==========================================================
 #==========================================================
 sub new {
@@ -54,20 +49,20 @@ my ($self, $x) = @_;
 #==========================================================
  #Converting from Degrees, Minutes and Seconds to Decimal Degrees
 sub DegreeToDecimal {
-my ($self, $Degrees, $Minutes, $Seconds) = @_;
-	return $Degrees + ($Minutes / 60) + ($Seconds / 3600);
+my ($self, $degrees, $minutes, $seconds) = @_;
+	return $degrees + ($minutes / 60) + ($seconds / 3600);
 }
 #==========================================================
 #Converting from Decimal Degrees to Degrees, Minutes and Seconds
 sub DecimalToDegree {
-my ($self, $DecimalDegree) = @_;
-my ($Degrees, $Minutes, $Seconds, $ff);
+my ($self, $decimal_degree) = @_;
+my ($degrees, $minutes, $seconds, $ff);
      
-    $Degrees = int($DecimalDegree);
-    $ff = $DecimalDegree - $Degrees;
-    $Minutes = int(60 * $ff);
-    $Seconds = 60 * ((60 * $ff) - $Minutes);
-	return ($Degrees, $Minutes, $Seconds);
+    $degrees = int($decimal_degree);
+    $ff = $decimal_degree - $degrees;
+    $minutes = int(60 * $ff);
+    $seconds = 60 * ((60 * $ff) - $minutes);
+	return ($degrees, $minutes, $seconds);
 }
 #==========================================================
 # The shortest distance between points 1 and 2 on the earth's surface is
@@ -92,36 +87,36 @@ my ($Degrees, $Minutes, $Seconds, $ff);
 
 # Calculates the distance between any two points on the Earth
 sub  GreatCircleDistance {
-my ($self, $OrigLat , $DestLat, $OrigLong, $DestLong) = @_;
-my ($D, $L1, $L2, $I1, $I2);
+my ($self, $orig_lat , $dest_lat, $orig_long, $dest_long) = @_;
+my ($d, $l1, $l2, $i1, $i2);
     
-    $L1 = $OrigLat * $DtoR;
-    $L2 = $DestLat * $DtoR;
-    $I1 = $OrigLong * $DtoR;
-    $I2 = $DestLong * $DtoR;
+    $l1 = $orig_lat * DtoR;
+    $l2 = $dest_lat * DtoR;
+    $i1 = $orig_long * DtoR;
+    $i2 = $dest_long * DtoR;
     
-    $D = $self->acos(cos($L1 - $L2) - (1 - cos($I1 - $I2)) * cos($L1) * cos($L2));
+    $d = $self->acos(cos($l1 - $l2) - (1 - cos($i1 - $i2)) * cos($l1) * cos($l2));
     # One degree of such an arc on the earth's surface is 60 international nautical miles NM
-    return $D * 60 * $RtoD;
+    return $d * 60 * RtoD;
 }
 #==========================================================
 #Calculates the direction from one point to another on the Earth
 # a = arccos{[sin(lat2) - cos(d + lat1 - 1.5708)]/cos(lat1)/sin(d) + 1}
 # Great Circle Bearing
 sub GreatCircleDirection {
-my ($self, $OrigLat, $DestLat, $OrigLong, $DestLong, $Distance) = @_;
-my ($A, $B, $D, $L1, $L2, $I1, $I2, $Result, $Dlong);
+my ($self, $orig_lat, $dest_lat, $orig_long, $dest_long, $distance) = @_;
+my ($a, $b, $d, $l1, $l2, $i1, $i2, $result, $dlong);
     
-	$L1 = $OrigLat * $DtoR;
-	$L2 = $DestLat * $DtoR;
-	$D = ($Distance / 60) * $DtoR; # divide by 60 for nautical miles NM to degree
+	$l1 = $orig_lat * DtoR;
+	$l2 = $dest_lat * DtoR;
+	$d = ($distance / 60) * DtoR; # divide by 60 for nautical miles NM to degree
 
-	$I1 = $OrigLong * $DtoR;
-	$I2 = $DestLong * $DtoR;
-	$Dlong = $I1 - $I2;
+	$i1 = $orig_long * DtoR;
+	$i2 = $dest_long * DtoR;
+	$dlong = $i1 - $i2;
 
-	$A = sin($L2) - cos($D + $L1 - $pi / 2);
-	$B = $self->acos($A / (cos($L1) * sin($D)) + 1);
+	$a = sin($l2) - cos($d + $l1 - PI / 2);
+	$b = $self->acos($a / (cos($l1) * sin($d)) + 1);
 
 	#If (Abs(Dlong) < pi And Dlong < 0) Or (Abs(Dlong) > pi And Dlong > 0) Then
 	#        Result = (2 * pi) - B
@@ -129,27 +124,26 @@ my ($A, $B, $D, $L1, $L2, $I1, $I2, $Result, $Dlong);
 	#        Result = B
 	#End If
 
-	$Result = $B;
-	return $Result * $RtoD;
+	$result = $b;
+	return $result * RtoD;
 }
 #==========================================================
 #The Equivalent Earth redius is 6,378.14 Kilometers.
 # Calculates the direction of the Qibla from any point on
 # the Earth From North Clocklwise
 sub QiblaDirection {
-my ($self, $OrigLat, $OrigLong) = @_;
-my ($Distance, $Bearing);
+my ($self, $orig_lat, $orig_long) = @_;
+my ($distance, $bearing);
     
 	# Kabah Lat=21 Deg N, Long 40 Deg E
-	$Distance = $self->GreatCircleDistance($OrigLat, $self->{DestLat}, $OrigLong, $self->{DestLong});
-	$Bearing = $self->GreatCircleDirection($OrigLat, $self->{DestLat}, $OrigLong, $self->{DestLong}, $Distance);
-	return $Bearing;
+	$distance = $self->GreatCircleDistance($orig_lat, $self->{DestLat}, $orig_long, $self->{DestLong});
+	$bearing = $self->GreatCircleDirection($orig_lat, $self->{DestLat}, $orig_long, $self->{DestLong}, $distance);
+	return $bearing;
 }
 #==========================================================
 #==========================================================
 
 1;
-__END__
 
 =head1 NAME
 
@@ -172,12 +166,12 @@ Religion::Islam::Qibla - Calculates the Muslim Qiblah Direction, Great Circle Di
 	print "The Qibla Direction for $Latitude and $Longitude From North Clocklwise is: " . $QiblaDirection ."\n";
 	
 	# Calculates the distance between any two points on the Earth
-	my $OrigLat = 31; my $DestLat = 21; my $OrigLong = 31.3; $DestLong = 40;
-	my $distance = $qibla->GreatCircleDistance($OrigLat , $DestLat, $OrigLong, $DestLong);
+	my $orig_lat = 31; my $dest_lat = 21; my $orig_long = 31.3; $dest_long = 40;
+	my $distance = $qibla->GreatCircleDistance($orig_lat , $dest_lat, $orig_long, $dest_long);
 	print "The distance is: $distance \n";
 
 	# Calculates the direction from one point to another on the Earth. Great Circle Bearing
-	my $direction = $qibla->GreatCircleDirection($OrigLat, $DestLat, $OrigLong, $DestLong, $Distance);
+	my $direction = $qibla->GreatCircleDirection($orig_lat, $dest_lat, $orig_long, $dest_long, $distance);
 	print "The direction is: $direction \n";
 	
 	# You can get and set the distination point Latitude and Longitude
@@ -193,18 +187,20 @@ also calculates and uses the Great Circle Distance and Great Circle Direction.
 
 =head1 SEE ALSO
 
-L<Religion::Islam::PrayerTimes>
+L<Date::HijriDate>
 L<Religion::Islam::Quran>
+L<Religion::Islam::PrayTime>
+L<Religion::Islam::PrayerTimes>
 
 =head1 AUTHOR
 
-Ahmed Amin Elsheshtawy, <support@islamware.com>
-Website: http://www.islamware.com
+Ahmed Amin Elsheshtawy,  <support@islamware.com> <support@mewsoft.com>
+Website: http://www.islamware.com   http://www.mewsoft.com
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Ahmed Amin Elsheshtawy support@islamware.com,
-L<http://www.islamware.com>
+Copyright (C) 2006-2013 by Ahmed Amin Elsheshtawy support@islamware.com, support@mewsoft.com
+L<http://www.islamware.com>  L<http://www.mewsoft.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
